@@ -34,12 +34,17 @@
 
 #include <QDir>
 #include <qplatformdefs.h>
+#include <QStandardPaths>
+#include <KConfigGroup>
+#include <KSharedConfig>
 
 // Reasonable line size
 static const int LINE_SIZE = 1024;
 
 using namespace Konsole;
 
+Q_GLOBAL_STATIC(QString, historyFileLocation);
+
 /*
    An arbitrary long scroll.
 
@@ -62,7 +67,21 @@ HistoryFile::HistoryFile()
       _fileMap(0),
       _readWriteBalance(0)
 {
-    const QString tmpFormat = QDir::tempPath() + QLatin1Char('/') + "konsole-XXXXXX.history";
+    // Determine the temp directory once
+    // This class is called 3 times for each "unlimited" scrollback.
+    // This has the down-side that users must restart to
+    // load changes (currently only 2 choices).
+    if (!historyFileLocation.exists()) {
+        KConfigGroup configGroup(KSharedConfig::openConfig(), "FileLocation");
+        if (configGroup.readEntry("scrollbackUseCacheLocation", false)) {
+            *historyFileLocation() = QStandardPaths::writableLocation(QStandardPaths::CacheLocation);
+        } else {
+            *historyFileLocation() = QDir::tempPath();
+        }
+        QDir().mkpath(*historyFileLocation());
+    }
+    const QString tmpDir = *historyFileLocation();
+    const QString tmpFormat = tmpDir + QLatin1Char('/') + "konsole-XXXXXX.history";
     _tmpFile.setFileTemplate(tmpFormat);
     if (_tmpFile.open()) {
         _tmpFile.setAutoRemove(true);
