@@ -22,6 +22,10 @@
 
 // Qt
 #include <QtGui/QKeyEvent>
+#include <QtGui/QIcon>
+
+// KDE
+#include <KLocalizedString>
 
 // Konsole
 #include "ui_KeyBindingEditor.h"
@@ -37,8 +41,7 @@ KeyBindingEditor::KeyBindingEditor(QWidget* parent)
     _ui->setupUi(this);
 
     // description edit
-    connect(_ui->descriptionEdit , SIGNAL(textChanged(QString)) ,
-            this , SLOT(setTranslatorDescription(QString)));
+    connect(_ui->descriptionEdit , &QLineEdit::textChanged , this , &Konsole::KeyBindingEditor::setTranslatorDescription);
 
     // key bindings table
     _ui->keyBindingTable->setColumnCount(2);
@@ -52,11 +55,11 @@ KeyBindingEditor::KeyBindingEditor(QWidget* parent)
     _ui->keyBindingTable->setSelectionBehavior(QAbstractItemView::SelectRows);
 
     // add and remove buttons
-    _ui->addEntryButton->setIcon(KIcon("list-add"));
-    _ui->removeEntryButton->setIcon(KIcon("list-remove"));
+    _ui->addEntryButton->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
+    _ui->removeEntryButton->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
 
-    connect(_ui->removeEntryButton , SIGNAL(clicked()) , this , SLOT(removeSelectedEntry()));
-    connect(_ui->addEntryButton , SIGNAL(clicked()) , this , SLOT(addNewEntry()));
+    connect(_ui->removeEntryButton , &QPushButton::clicked , this , &Konsole::KeyBindingEditor::removeSelectedEntry);
+    connect(_ui->addEntryButton , &QPushButton::clicked , this , &Konsole::KeyBindingEditor::addNewEntry);
 
     // test area
     _ui->testAreaInputEdit->installEventFilter(this);
@@ -114,11 +117,11 @@ bool KeyBindingEditor::eventFilter(QObject* watched , QEvent* event)
 {
     if (watched == _ui->testAreaInputEdit) {
         if (event->type() == QEvent::KeyPress) {
-            QKeyEvent* keyEvent = (QKeyEvent*)event;
+            QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
 
             // The state here is currently set to the state that a newly started
             // terminal in Konsole will be in ( which is also the same as the
-            // state just after a reset ), this has 'Ansi' turned on and all other
+            // state just after a reset ), this has 'ANSI' turned on and all other
             // states off.
             //
             // TODO: It may be useful to be able to specify the state in the 'test input'
@@ -171,7 +174,7 @@ void KeyBindingEditor::setup(const KeyboardTranslator* translator)
     _translator = new KeyboardTranslator(*translator);
 
     // setup description edit
-    _ui->descriptionEdit->setClearButtonShown(true);
+    _ui->descriptionEdit->setClearButtonEnabled(true);
     _ui->descriptionEdit->setText(translator->description());
 
     // setup key binding table
@@ -204,8 +207,8 @@ void KeyBindingEditor::bindingTableItemChanged(QTableWidgetItem* item)
 
 void KeyBindingEditor::setupKeyBindingTable(const KeyboardTranslator* translator)
 {
-    disconnect(_ui->keyBindingTable , SIGNAL(itemChanged(QTableWidgetItem*)) , this ,
-               SLOT(bindingTableItemChanged(QTableWidgetItem*)));
+    disconnect(_ui->keyBindingTable , &QTableWidget::itemChanged , this ,
+               &Konsole::KeyBindingEditor::bindingTableItemChanged);
 
     QList<KeyboardTranslator::Entry> entries = translator->entries();
     _ui->keyBindingTable->setRowCount(entries.count());
@@ -223,9 +226,6 @@ void KeyBindingEditor::setupKeyBindingTable(const KeyboardTranslator* translator
     }
     _ui->keyBindingTable->sortItems(0);
 
-    connect(_ui->keyBindingTable , SIGNAL(itemChanged(QTableWidgetItem*)) , this ,
-            SLOT(bindingTableItemChanged(QTableWidgetItem*)));
+    connect(_ui->keyBindingTable , &QTableWidget::itemChanged , this , &Konsole::KeyBindingEditor::bindingTableItemChanged);
 }
 
-#include "KeyBindingEditor.moc"
-
