@@ -357,6 +357,10 @@ class KeyboardTranslatorReader
 public:
     /** Constructs a new reader which parses the given @p source */
     explicit KeyboardTranslatorReader(QIODevice* source);
+    ~KeyboardTranslatorReader();
+
+    KeyboardTranslatorReader(const KeyboardTranslatorReader&) = delete;
+    KeyboardTranslatorReader& operator=(const KeyboardTranslatorReader&) = delete;
 
     /**
      * Returns the description text.
@@ -427,6 +431,9 @@ public:
     explicit KeyboardTranslatorWriter(QIODevice* destination);
     ~KeyboardTranslatorWriter();
 
+    KeyboardTranslatorWriter(const KeyboardTranslatorWriter&) = delete;
+    KeyboardTranslatorWriter& operator=(const KeyboardTranslatorWriter&) = delete;
+
     /**
      * Writes the header for the keyboard translator.
      * @param description Description of the keyboard translator.
