@@ -27,11 +27,11 @@
 
 // Qt
 #include <QtCore/QStringList>
+#include <qplatformdefs.h>
 
 // KDE
 #include <QDebug>
 #include <KPtyDevice>
-#include <kde_file.h>
 
 using Konsole::Pty;
 
@@ -260,17 +260,19 @@ int Pty::start(const QString& programName,
 
 void Pty::setWriteable(bool writeable)
 {
-    KDE_struct_stat sbuf;
-    if (KDE::stat(pty()->ttyName(), &sbuf) == 0) {
+    QT_STATBUF sbuf;
+    if (QT_STAT(pty()->ttyName(), &sbuf) == 0) {
         if (writeable) {
-            if (KDE::chmod(pty()->ttyName(), sbuf.st_mode | S_IWGRP) < 0) {
+            if (::chmod(pty()->ttyName(), sbuf.st_mode | S_IWGRP) < 0) {
                 qWarning() << "Could not set writeable on "<<pty()->ttyName();
             }
         } else {
-            if (KDE::chmod(pty()->ttyName(), sbuf.st_mode & ~(S_IWGRP | S_IWOTH)) < 0) {
+            if (::chmod(pty()->ttyName(), sbuf.st_mode & ~(S_IWGRP | S_IWOTH)) < 0) {
                 qWarning() << "Could not unset writeable on "<<pty()->ttyName();
             }
         }
+    } else {
+        qWarning() << "Could not stat "<<pty()->ttyName();
     }
 }
 
