@@ -25,7 +25,7 @@
 
 using namespace Konsole;
 
-ScreenWindow::ScreenWindow(QObject* parent)
+ScreenWindow::ScreenWindow(Screen* screen, QObject* parent)
     : QObject(parent)
     , _windowBuffer(0)
     , _windowBufferSize(0)
@@ -36,6 +36,7 @@ ScreenWindow::ScreenWindow(QObject* parent)
     , _trackOutput(true)
     , _scrollCount(0)
 {
+    setScreen(screen);
 }
 
 ScreenWindow::~ScreenWindow()
@@ -119,9 +120,9 @@ QVector<LineProperty> ScreenWindow::getLineProperties()
     return result;
 }
 
-QString ScreenWindow::selectedText(bool preserveLineBreaks, bool trimTrailingSpaces) const
+QString ScreenWindow::selectedText(bool preserveLineBreaks, bool trimTrailingSpaces, bool html) const
 {
-    return _screen->selectedText(preserveLineBreaks, trimTrailingSpaces);
+    return _screen->selectedText(preserveLineBreaks, trimTrailingSpaces, html);
 }
 
 void ScreenWindow::getSelectionStart(int& column , int& line)
@@ -318,4 +319,3 @@ void ScreenWindow::notifyOutputChanged()
     emit outputChanged();
 }
 
-#include "ScreenWindow.moc"
