@@ -23,9 +23,10 @@
 #include "SessionListModel.h"
 
 // KDE
-#include <KIcon>
 #include <KLocalizedString>
 
+#include <QtGui/QIcon>
+
 // Konsole
 #include "Session.h"
 
@@ -42,7 +43,7 @@ void SessionListModel::setSessions(const QList<Session*>& sessions)
     _sessions = sessions;
 
     foreach(Session * session, sessions) {
-        connect(session, SIGNAL(finished()), this, SLOT(sessionFinished()));
+        connect(session, &Konsole::Session::finished, this, &Konsole::SessionListModel::sessionFinished);
     }
 
     reset();
@@ -77,7 +78,7 @@ QVariant SessionListModel::data(const QModelIndex& index, int role) const
         break;
     case Qt::DecorationRole:
         if (column == 1)
-            return KIcon(_sessions[row]->iconName());
+            return QIcon::fromTheme(_sessions[row]->iconName());
         else
             return QVariant();
     }
@@ -141,4 +142,3 @@ QModelIndex SessionListModel::index(int row, int column, const QModelIndex& pare
         return QModelIndex();
 }
 
-#include "SessionListModel.moc"
