@@ -550,7 +550,7 @@ void TabbedViewContainer::openTabContextMenu(const QPoint& pos)
 #if defined(ENABLE_DETACHING)
     // Enable 'Detach Tab' menu item only if there is more than 1 tab
     // Note: the code is coupled with that action's position within the menu
-    QAction* detachAction = _contextPopupMenu->actions().first();
+    QAction* detachAction = _contextPopupMenu->actions().at(0);
     detachAction->setEnabled(_tabBar->count() > 1);
 #endif
 
