@@ -25,6 +25,7 @@
 #include <QVBoxLayout>
 #include <QFileInfo>
 #include <QTimer>
+#include <QDialog>
 // KDE
 #include <KPluginLoader>
 #include <KPluginFactory>
@@ -32,8 +33,6 @@
 #include <KParts/Part>
 #include <KPtyProcess>
 #include <KPtyDevice>
-#include <KDialog>
-#include <KMainWindow>
 #include <qtest.h>
 
 // Konsole
@@ -47,7 +46,7 @@ void PartTest::testFd()
     QStringList pingList;
     QFileInfo info;
     QString pingExe;
-    pingList << "/bin/ping" << "/sbin/ping";
+    pingList << QStringLiteral("/bin/ping") << QStringLiteral("/sbin/ping");
     for (int i = 0; i < pingList.size(); ++i) {
         info.setFile(pingList.at(i));
         if (info.exists() && info.isExecutable())
@@ -68,7 +67,7 @@ void PartTest::testFd()
 
     // start a pty process
     KPtyProcess ptyProcess;
-    ptyProcess.setProgram(pingExe, QStringList() << "localhost");
+    ptyProcess.setProgram(pingExe, QStringList() << QStringLiteral("localhost"));
     ptyProcess.setPtyChannels(KPtyProcess::AllChannels);
     ptyProcess.start();
     QVERIFY(ptyProcess.waitForStarted());
@@ -84,10 +83,9 @@ void PartTest::testFd()
     // as soon as it becomes available and the terminal will not display any output
     ptyProcess.pty()->setSuspended(true);
 
-    QWeakPointer<KDialog> dialog = new KDialog();
-    dialog.data()->setButtons(0);
-    QVBoxLayout* layout = new QVBoxLayout(dialog.data()->mainWidget());
-    layout->addWidget(new QLabel("Output of 'ping localhost' should appear in a terminal below for 5 seconds"));
+    QWeakPointer<QDialog> dialog = new QDialog();
+    QVBoxLayout* layout = new QVBoxLayout(dialog.data());
+    layout->addWidget(new QLabel(QStringLiteral("Output of 'ping localhost' should appear in a terminal below for 5 seconds")));
     layout->addWidget(terminalPart->widget());
     QTimer::singleShot(5000, dialog.data(), SLOT(close()));
     dialog.data()->exec();
@@ -100,7 +98,7 @@ void PartTest::testFd()
 
 KParts::Part* PartTest::createPart()
 {
-    KService::Ptr service = KService::serviceByDesktopName("konsolepart");
+    KService::Ptr service = KService::serviceByDesktopName(QStringLiteral("konsolepart"));
     if (!service)       // not found
         return 0;
     KPluginFactory* factory = KPluginLoader(service->library()).factory();
